@@ -1,4 +1,4 @@
-# $Id: test_forecast.py 1447 2016-02-06 16:56:24Z mwall $
+# $Id: test_forecast.py 1666 2017-02-05 23:09:22Z mwall $
 # Copyright: 2013 Matthew Wall
 # License: GPLv3
 
@@ -837,6 +837,7 @@ class ForecastTest(unittest.TestCase):
         event.record = { 'dateTime': ts }
         record = zf.get_forecast(event)
         self.assertEqual(record, [{'event_ts': 1409058000, 'dateTime': 1409087474, 'zcode': 'X', 'issued_ts': 1409087474, 'method': 'Zambretti', 'usUnits': 1}])
+        # FIXME: this code was 'P'
 
         # check the forecast a few hours later (should be same forecast)
         ts = ts0 + 2*3600 # 26 aug 2014 23:11:12 GMT
@@ -849,6 +850,7 @@ class ForecastTest(unittest.TestCase):
         event.record = { 'dateTime': ts }
         record = zf.get_forecast(event)
         self.assertEqual(record, [{'event_ts': 1408971600, 'dateTime': 1409001074, 'zcode': 'B', 'issued_ts': 1409001074, 'method': 'Zambretti', 'usUnits': 1}])
+        # FIXME: this code was 'A'
 
         # now the pressure goes up slightly
         FakeData.create_weather_database(
@@ -903,6 +905,7 @@ class ForecastTest(unittest.TestCase):
             interval=600, units=units)
         record = zf.get_forecast(event)
         self.assertEqual(record, [{'event_ts': 1409058000, 'dateTime': 1409087474, 'zcode': 'X', 'issued_ts': 1409087474, 'method': 'Zambretti', 'usUnits': 1}])
+        # FIXME: this code was 'P'
 
     def test_zambretti_bogus_values(self):
         '''confirm behavior when we get bogus values'''
@@ -1081,6 +1084,17 @@ $forecast.zambretti.code
         for label in expected.keys():
             self.assertEqual(matrix[label], expected[label])
 
+    def test_nws_parse_5(self):
+        # this forecast was downloaded around 13:00 on 05feb2017
+        # it has leading negative double-digit values for TEMP and DEWPT
+        data = readfile('PFM_BIS_170205')
+        matrix = forecast.NWSParseForecast(data, 'NDZ011')
+        expected = {}
+        expected['temp'] = [None, None, None, '8', '13', '13', '13', '11', '10', '7', '5', '7', '7', '8', '5', '3', '1', '-1', '-3', '0', '2', '0', '-10', '-13', '-4', '-5', '-8', '-5', '11', '16', '18', '22', '33', '32', '25', '17', '21', '22']
+        expected['dewpoint'] = [None, None, None, '1', '6', '7', '10', '9', '6', '3', '1', '2', '3', '2', '0', '-2', '-4', '-7', '-8', '-7', '-6', '-9', '-14', '-19', '-14', '-11', '-13', '-10', '2', '8', '14', '18', '27', '25', '17', '12', '15', '14']
+        for label in expected.keys():
+            self.assertEqual(matrix[label], expected[label])
+
     def test_nws_template_periods(self):
         data = readfile('PFM_BOS_SINGLE')
         matrix = forecast.NWSParseForecast(data, 'MAZ014')
@@ -2011,10 +2025,10 @@ $a.moon_fullness
   <body>
 07:13
 16:21
-34
+48
 07:13
 16:23
-55
+66
   </body>
 </html>
 ''')
@@ -2037,13 +2051,13 @@ $ts $a.sunrise $a.sunset $gmstr
 ''',
                              '''<html>
   <body>
-1381536000 06:53 18:09 2013.10.12 00:00:00 UTC
-1381579200 06:54 18:07 2013.10.12 12:00:00 UTC
-1381622400 06:54 18:07 2013.10.13 00:00:00 UTC
-1381665600 06:55 18:05 2013.10.13 12:00:00 UTC
-1381708800 06:55 18:05 2013.10.14 00:00:00 UTC
-1381752000 06:56 18:04 2013.10.14 12:00:00 UTC
-1381795200 06:56 18:04 2013.10.15 00:00:00 UTC
+1381536000 06:52 18:08 2013.10.12 00:00:00 UTC
+1381579200 06:53 18:07 2013.10.12 12:00:00 UTC
+1381622400 06:53 18:07 2013.10.13 00:00:00 UTC
+1381665600 06:54 18:05 2013.10.13 12:00:00 UTC
+1381708800 06:54 18:05 2013.10.14 00:00:00 UTC
+1381752000 06:56 18:03 2013.10.14 12:00:00 UTC
+1381795200 06:56 18:03 2013.10.15 00:00:00 UTC
 1381838400 06:57 18:02 2013.10.15 12:00:00 UTC
   </body>
 </html>
